summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorValentin Lorentz <progval+git@progval.net>2022-04-06 20:31:16 +0200
committerSébastien Helleu <flashcode@flashtux.org>2022-07-02 20:34:31 +0200
commitfa05f75b74ff392d10292bca41e8106ebca32341 (patch)
treedd7432399e377dc765b30e4595c5bb9593c149ad /src
parenta96d2c28fb5d5b9c8adbc1cae577b30d499ba4c0 (diff)
downloadweechat-fa05f75b74ff392d10292bca41e8106ebca32341.zip
irc: add ERR_HELPNOTFOUND (issue #1772)
Diffstat (limited to 'src')
-rw-r--r--src/plugins/irc/irc-protocol.c6
1 files changed, 5 insertions, 1 deletions
diff --git a/src/plugins/irc/irc-protocol.c b/src/plugins/irc/irc-protocol.c
index ba84511c0..61ee169a9 100644
--- a/src/plugins/irc/irc-protocol.c
+++ b/src/plugins/irc/irc-protocol.c
@@ -6580,7 +6580,7 @@ IRC_PROTOCOL_CALLBACK(470)
}
/*
* Callback for the IRC commands "704", "705", and "706": help reply.
*
* Commands look like:
* 704 mynick topic :First help line of <topic>
@@ -6588,6 +6588,9 @@ IRC_PROTOCOL_CALLBACK(470)
* 705 mynick topic :and this
* 705 mynick topic :and that.
* 706 mynick topic :Last help line of <topic>
+ *
+ * Or:
+ * 524 mynick topic :help not found
*/
IRC_PROTOCOL_CALLBACK(help)
{
@@ -7279,6 +7282,7 @@ irc_protocol_recv_command (struct t_irc_server *server,
IRCB(491, 1, 0, generic_error), /* no O-lines for your host */
IRCB(501, 1, 0, generic_error), /* unknown mode flag */
IRCB(502, 1, 0, generic_error), /* can't chg mode for other users */
+ IRCB(524, 1, 0, help), /* HELP/HELPOP reply (help not found) */
IRCB(671, 1, 0, whois_nick_msg), /* whois (secure connection) */
IRCB(704, 1, 0, help), /* start of HELP/HELPOP reply */
IRCB(705, 1, 0, help), /* main HELP/HELPOP reply */
@@ -6580,7 +6580,7 @@ IRC_PROTOCOL_CALLBACK(470)
}
/*
- * Callback for the IRC commands "704", "705", and "706": help reply.
+ * Callback for the IRC commands "524", "704", "705", and "706": help reply.
*
* Commands look like: